@@ -19,6 +19,28 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+/**
+ * SECTION:completioncontext
+ * @title: GtkSourceCompletionContext
+ * @short_description: The context of a completion
+ *
+ * A completion context is created when a completion occurs. The completion can
+ * be activated by several means, listed in #GtkSourceCompletionActivation.
+ *
+ * The completion can be activated by user request, i.e. when the user presses
+ * <keycombo><keycap>Control</keycap><keycap>space</keycap></keycombo>, by default.
+ *
+ * The completion can also be activated interactively, on each insertion or
+ * deletion in the #GtkTextBuffer.
+ *
+ * A #GtkTextIter is associated with the context, this is where the completion
+ * takes place. With this #GtkTextIter, you can get the associated
+ * #GtkTextBuffer with gtk_text_iter_get_buffer().
+ *
+ * Once the context is created, the eligible providers are asked to add
+ * proposals with gtk_source_completion_context_add_proposals().
+ */
+
 #include "gtksourcecompletioncontext.h"
 #include "gtksourceview-typebuiltins.h"
 #include "gtksourcecompletionprovider.h"
@@ -80,7 +102,7 @@ gtk_source_completion_context_dispose (GObject *object)
 	context = GTK_SOURCE_COMPLETION_CONTEXT (object);
 	buffer = get_buffer (context);
 
-	if (context->priv->mark_set_id)
+	if (context->priv->mark_set_id != 0)
 	{
 		g_signal_handler_disconnect (buffer, context->priv->mark_set_id);
 		context->priv->mark_set_id = 0;
@@ -88,7 +110,7 @@ gtk_source_completion_context_dispose (GObject *object)
 
 	g_clear_object (&context->priv->completion);
 
-	if (context->priv->mark)
+	if (context->priv->mark != NULL)
 	{
 		gtk_text_buffer_delete_mark (buffer, context->priv->mark);
 		context->priv->mark = NULL;
@@ -283,6 +305,8 @@ gtk_source_completion_context_init (GtkSourceCompletionContext *context)
  * can do so asynchronously by means of the @finished argument. Providers must
  * ensure that they always call this function with @finished set to %TRUE
  * once each population (even if no proposals need to be added).
+ * Population occurs when the gtk_source_completion_provider_populate()
+ * function is called.
  **/
 void
 gtk_source_completion_context_add_proposals (GtkSourceCompletionContext  *context,
