@@ -22,13 +22,15 @@
 #ifndef __GTK_SOURCE_COMPLETION_ITEM_H__
 #define __GTK_SOURCE_COMPLETION_ITEM_H__
 
-#include <gtk/gtk.h>
+#include <glib-object.h>
 #include <gtksourceview/gtksourcetypes.h>
+#include <gtksourceview/gtksourcecompletionproposal.h>
 
 G_BEGIN_DECLS
 
 #define GTK_SOURCE_TYPE_COMPLETION_ITEM			(gtk_source_completion_item_get_type ())
 #define GTK_SOURCE_COMPLETION_ITEM(obj)			(G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_SOURCE_TYPE_COMPLETION_ITEM, GtkSourceCompletionItem))
+#define GTK_SOURCE_COMPLETION_ITEM_CONST(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_SOURCE_TYPE_COMPLETION_ITEM, GtkSourceCompletionItem const))
 #define GTK_SOURCE_COMPLETION_ITEM_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST ((klass), GTK_SOURCE_TYPE_COMPLETION_ITEM, GtkSourceCompletionItemClass))
 #define GTK_SOURCE_IS_COMPLETION_ITEM(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_SOURCE_TYPE_COMPLETION_ITEM))
 #define GTK_SOURCE_IS_COMPLETION_ITEM_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_SOURCE_TYPE_COMPLETION_ITEM))
@@ -59,7 +61,6 @@ GtkSourceCompletionItem *gtk_source_completion_item_new_with_markup	(const gchar
 									 GdkPixbuf   *icon,
 									 const gchar *info);
 
-G_DEPRECATED_FOR (gtk_source_completion_item_new)
 GtkSourceCompletionItem *gtk_source_completion_item_new_from_stock	(const gchar *label,
 								 	 const gchar *text,
 								 	 const gchar *stock,
