@@ -23,8 +23,9 @@
 #define __GTK_SOURCE_COMPLETION_MODEL_H__
 
 #include <gtk/gtk.h>
-#include "gtksourcetypes.h"
-#include "gtksourcetypes-private.h"
+#include <gtksourceview/gtksourcetypes.h>
+#include <gtksourceview/gtksourcecompletionprovider.h>
+#include <gtksourceview/gtksourcecompletionproposal.h>
 
 G_BEGIN_DECLS
 
@@ -49,81 +50,63 @@ struct _GtkSourceCompletionModelClass {
 	GObjectClass parent_class;
 
 	void (*providers_changed) 	(GtkSourceCompletionModel *model);
+	void (*begin_delete)		(GtkSourceCompletionModel *model);
+	void (*end_delete)		(GtkSourceCompletionModel *model);
 };
 
 enum
 {
+	GTK_SOURCE_COMPLETION_MODEL_COLUMN_LABEL,
 	GTK_SOURCE_COMPLETION_MODEL_COLUMN_MARKUP,
 	GTK_SOURCE_COMPLETION_MODEL_COLUMN_ICON,
-	GTK_SOURCE_COMPLETION_MODEL_COLUMN_ICON_NAME,
-	GTK_SOURCE_COMPLETION_MODEL_COLUMN_GICON,
 	GTK_SOURCE_COMPLETION_MODEL_COLUMN_PROPOSAL,
 	GTK_SOURCE_COMPLETION_MODEL_COLUMN_PROVIDER,
-	GTK_SOURCE_COMPLETION_MODEL_COLUMN_IS_HEADER,
 	GTK_SOURCE_COMPLETION_MODEL_N_COLUMNS
 };
 
-G_GNUC_INTERNAL
-GType    gtk_source_completion_model_get_type			(void) G_GNUC_CONST;
+GType gtk_source_completion_model_get_type (void) G_GNUC_CONST;
 
-G_GNUC_INTERNAL
 GtkSourceCompletionModel *
-         gtk_source_completion_model_new			(void);
+		gtk_source_completion_model_new 	(void);
 
-G_GNUC_INTERNAL
-void     gtk_source_completion_model_add_proposals              (GtkSourceCompletionModel    *model,
-								 GtkSourceCompletionProvider *provider,
-								 GList                       *proposals);
+void		gtk_source_completion_model_begin	(GtkSourceCompletionModel           *model,
+                                                         GList                              *providers);
+void		gtk_source_completion_model_append 	(GtkSourceCompletionModel           *model,
+							 GtkSourceCompletionProvider        *provider,
+							 GList                              *proposals);
+void		gtk_source_completion_model_end		(GtkSourceCompletionModel           *model,
+							 GtkSourceCompletionProvider        *provider);
+void		gtk_source_completion_model_cancel	(GtkSourceCompletionModel           *model);
 
-G_GNUC_INTERNAL
-gboolean gtk_source_completion_model_is_empty			(GtkSourceCompletionModel    *model,
-								 gboolean                     only_visible);
+gboolean	gtk_source_completion_model_is_empty 	(GtkSourceCompletionModel           *model,
+                                                         gboolean                            invisible);
 
-G_GNUC_INTERNAL
-void     gtk_source_completion_model_set_visible_providers	(GtkSourceCompletionModel    *model,
-								 GList                       *providers);
+void            gtk_source_completion_model_set_visible_providers (GtkSourceCompletionModel *model,
+                                                                   GList                    *providers);
+GList          *gtk_source_completion_model_get_visible_providers (GtkSourceCompletionModel *model);
 
-G_GNUC_INTERNAL
-GList   *gtk_source_completion_model_get_visible_providers	(GtkSourceCompletionModel    *model);
 
-G_GNUC_INTERNAL
-GList   *gtk_source_completion_model_get_providers		(GtkSourceCompletionModel    *model);
+GList          *gtk_source_completion_model_get_providers (GtkSourceCompletionModel         *model);
+guint		gtk_source_completion_model_n_proposals (GtkSourceCompletionModel           *model,
+                                                         GtkSourceCompletionProvider        *provider);
 
-G_GNUC_INTERNAL
-void     gtk_source_completion_model_set_show_headers		(GtkSourceCompletionModel    *model,
-								 gboolean                     show_headers);
+void 		gtk_source_completion_model_clear 	(GtkSourceCompletionModel           *model);
 
-G_GNUC_INTERNAL
-gboolean gtk_source_completion_model_iter_is_header		(GtkSourceCompletionModel    *model,
-								 GtkTreeIter                 *iter);
+void 		gtk_source_completion_model_set_show_headers (GtkSourceCompletionModel      *model,
+							      gboolean                       show_headers);
 
-G_GNUC_INTERNAL
-gboolean gtk_source_completion_model_iter_previous		(GtkSourceCompletionModel    *model,
-								 GtkTreeIter                 *iter);
+gboolean	gtk_source_completion_model_iter_is_header (GtkSourceCompletionModel        *model,
+                                                            GtkTreeIter                     *iter);
 
-G_GNUC_INTERNAL
-gboolean gtk_source_completion_model_first_proposal             (GtkSourceCompletionModel    *model,
-								 GtkTreeIter                 *iter);
+gboolean 	gtk_source_completion_model_iter_previous (GtkSourceCompletionModel         *model,
+							   GtkTreeIter                      *iter);
 
-G_GNUC_INTERNAL
-gboolean gtk_source_completion_model_last_proposal              (GtkSourceCompletionModel    *model,
-								 GtkTreeIter                 *iter);
+gboolean 	gtk_source_completion_model_iter_last 	(GtkSourceCompletionModel           *model,
+							 GtkTreeIter                        *iter);
 
-G_GNUC_INTERNAL
-gboolean gtk_source_completion_model_next_proposal              (GtkSourceCompletionModel    *model,
-								 GtkTreeIter                 *iter);
-
-G_GNUC_INTERNAL
-gboolean gtk_source_completion_model_previous_proposal          (GtkSourceCompletionModel    *model,
-								 GtkTreeIter                 *iter);
-
-G_GNUC_INTERNAL
-gboolean gtk_source_completion_model_has_info                   (GtkSourceCompletionModel    *model);
-
-G_GNUC_INTERNAL
-gboolean gtk_source_completion_model_iter_equal			(GtkSourceCompletionModel    *model,
-								 GtkTreeIter                 *iter1,
-								 GtkTreeIter                 *iter2);
+gboolean	gtk_source_completion_model_iter_equal	(GtkSourceCompletionModel           *model,
+							 GtkTreeIter                        *iter1,
+							 GtkTreeIter                        *iter2);
 
 G_END_DECLS
 
