@@ -28,17 +28,9 @@
  *
  * You must implement this interface to provide proposals to #GtkSourceCompletion
  *
- * The provider may be displayed in the completion window as a header row, showing
- * its name and optionally an icon.
- * The icon may be specified as a #GdkPixbuf, as an icon name or as a #GIcon by
- * implementing the corresponding get function. At most one of those get functions
- * should return a value different from %NULL, if they all return %NULL no icon
- * will be used.
  */
 
-#include "gtksourcecompletionprovider.h"
-#include "gtksourcecompletionproposal.h"
-#include "gtksourcecompletioninfo.h"
+#include <gtksourceview/gtksourcecompletionprovider.h>
 
 typedef GtkSourceCompletionProviderIface GtkSourceCompletionProviderInterface;
 
@@ -57,18 +49,6 @@ gtk_source_completion_provider_get_icon_default (GtkSourceCompletionProvider *pr
 	return NULL;
 }
 
-static const gchar *
-gtk_source_completion_provider_get_icon_name_default (GtkSourceCompletionProvider *provider)
-{
-	return NULL;
-}
-
-static GIcon *
-gtk_source_completion_provider_get_gicon_default (GtkSourceCompletionProvider *provider)
-{
-	return NULL;
-}
-
 static void
 gtk_source_completion_provider_populate_default (GtkSourceCompletionProvider *provider,
                                                  GtkSourceCompletionContext  *context)
@@ -138,10 +118,7 @@ static void
 gtk_source_completion_provider_default_init (GtkSourceCompletionProviderIface *iface)
 {
 	iface->get_name = gtk_source_completion_provider_get_name_default;
-
 	iface->get_icon = gtk_source_completion_provider_get_icon_default;
-	iface->get_icon_name = gtk_source_completion_provider_get_icon_name_default;
-	iface->get_gicon = gtk_source_completion_provider_get_gicon_default;
 
 	iface->populate = gtk_source_completion_provider_populate_default;
 
@@ -180,9 +157,9 @@ gtk_source_completion_provider_get_name (GtkSourceCompletionProvider *provider)
  * gtk_source_completion_provider_get_icon:
  * @provider: The #GtkSourceCompletionProvider
  *
- * Get the #GdkPixbuf for the icon of the @provider.
+ * Get the icon of the provider.
  *
- * Returns: (nullable) (transfer none): The icon to be used for the provider,
+ * Returns: (transfer none): The icon to be used for the provider,
  *          or %NULL if the provider does not have a special icon.
  */
 GdkPixbuf *
@@ -193,44 +170,6 @@ gtk_source_completion_provider_get_icon (GtkSourceCompletionProvider *provider)
 	return GTK_SOURCE_COMPLETION_PROVIDER_GET_INTERFACE (provider)->get_icon (provider);
 }
 
-/**
- * gtk_source_completion_provider_get_icon_name:
- * @provider: The #GtkSourceCompletionProvider
- *
- * Gets the icon name of @provider.
- *
- * Returns: (nullable) (transfer none): The icon name to be used for the provider,
- *          or %NULL if the provider does not have a special icon.
- *
- * Since: 3.18
- */
-const gchar *
-gtk_source_completion_provider_get_icon_name (GtkSourceCompletionProvider *provider)
-{
-	g_return_val_if_fail (GTK_SOURCE_IS_COMPLETION_PROVIDER (provider), NULL);
-
-	return GTK_SOURCE_COMPLETION_PROVIDER_GET_INTERFACE (provider)->get_icon_name (provider);
-}
-
-/**
- * gtk_source_completion_provider_get_gicon:
- * @provider: The #GtkSourceCompletionProvider
- *
- * Gets the #GIcon for the icon of @provider.
- *
- * Returns: (nullable) (transfer none): The icon to be used for the provider,
- *          or %NULL if the provider does not have a special icon.
- *
- * Since: 3.18
- */
-GIcon *
-gtk_source_completion_provider_get_gicon (GtkSourceCompletionProvider *provider)
-{
-	g_return_val_if_fail (GTK_SOURCE_IS_COMPLETION_PROVIDER (provider), NULL);
-
-	return GTK_SOURCE_COMPLETION_PROVIDER_GET_INTERFACE (provider)->get_gicon (provider);
-}
-
 /**
  * gtk_source_completion_provider_populate:
  * @provider: a #GtkSourceCompletionProvider.
@@ -293,21 +232,13 @@ gtk_source_completion_provider_match (GtkSourceCompletionProvider *provider,
  * This allows for customized widgets on a proposal basis, although in general
  * providers will have the same custom widget for all their proposals and
  * @proposal can be ignored. The implementation of this function is optional.
+ * If implemented, #gtk_source_completion_provider_update_info MUST also be
+ * implemented. If not implemented, the default
+ * #gtk_source_completion_proposal_get_info will be used to display extra
+ * information about a #GtkSourceCompletionProposal.
  *
- * If this function is not implemented, the default widget is a #GtkLabel. The
- * return value of gtk_source_completion_proposal_get_info() is used as the
- * content of the #GtkLabel.
- *
- * <note>
- *   <para>
- *     If implemented, gtk_source_completion_provider_update_info()
- *     <emphasis>must</emphasis> also be implemented.
- *   </para>
- * </note>
- *
- * Returns: (nullable) (transfer none): a custom #GtkWidget to show extra
- * information about @proposal, or %NULL if the provider does not have a special
- * info widget.
+ * Returns: (transfer none): a custom #GtkWidget to show extra
+ * information about @proposal.
  */
 GtkWidget *
 gtk_source_completion_provider_get_info_widget (GtkSourceCompletionProvider *provider,
@@ -326,13 +257,8 @@ gtk_source_completion_provider_get_info_widget (GtkSourceCompletionProvider *pro
  * @info: a #GtkSourceCompletionInfo.
  *
  * Update extra information shown in @info for @proposal.
- *
- * <note>
- *   <para>
- *     This function <emphasis>must</emphasis> be implemented when
- *     gtk_source_completion_provider_get_info_widget() is implemented.
- *   </para>
- * </note>
+ * This function MUST be implemented when
+ * #gtk_source_completion_provider_get_info_widget is implemented.
  */
 void
 gtk_source_completion_provider_update_info (GtkSourceCompletionProvider *provider,
@@ -351,16 +277,12 @@ gtk_source_completion_provider_update_info (GtkSourceCompletionProvider *provide
  * @provider: a #GtkSourceCompletionProvider.
  * @proposal: a #GtkSourceCompletionProposal.
  * @context: a #GtkSourceCompletionContext.
- * @iter: (out): a #GtkTextIter.
+ * @iter: a #GtkTextIter.
  *
  * Get the #GtkTextIter at which the completion for @proposal starts. When
- * implemented, this information is used to position the completion window
- * accordingly when a proposal is selected in the completion window. The
- * @proposal text inside the completion window is aligned on @iter.
- *
- * If this function is not implemented, the word boundary is taken to position
- * the completion window. See gtk_source_completion_provider_activate_proposal()
- * for an explanation on the word boundaries.
+ * implemented, the completion can use this information to position the
+ * completion window accordingly when a proposal is selected in the completion
+ * window.
  *
  * When the @proposal is activated, the default handler uses @iter as the start
  * of the word to replace. See
@@ -397,7 +319,7 @@ gtk_source_completion_provider_get_start_iter (GtkSourceCompletionProvider *prov
  *
  * Here is how the default activation selects the boundaries of the word to
  * replace. The end of the word is @iter. For the start of the word, it depends
- * on whether a start iter is defined for @proposal (see
+ * on wheter a start iter is defined for @proposal (see
  * gtk_source_completion_provider_get_start_iter()). If a start iter is defined,
  * the start of the word is the start iter. Else, the word (as long as possible)
  * will contain only alphanumerical and the "_" characters.
@@ -424,7 +346,7 @@ gtk_source_completion_provider_activate_proposal (GtkSourceCompletionProvider *p
  *
  * Get the delay in milliseconds before starting interactive completion for
  * this provider. A value of -1 indicates to use the default value as set
- * by the #GtkSourceCompletion:auto-complete-delay property.
+ * by #GtkSourceCompletion::auto-complete-delay.
  *
  * Returns: the interactive delay in milliseconds.
  **/
