@@ -19,13 +19,12 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef GTK_SOURCE_GUTTER_RENDERER_MARKS_H
-#define GTK_SOURCE_GUTTER_RENDERER_MARKS_H
+#ifndef __GTK_SOURCE_GUTTER_RENDERER_MARKS_H__
+#define __GTK_SOURCE_GUTTER_RENDERER_MARKS_H__
 
+#include <gtksourceview/gtksourcetypes.h>
+#include <gtksourceview/gtksourcegutterrendererpixbuf.h>
 #include <gtk/gtk.h>
-#include "gtksourcetypes.h"
-#include "gtksourcetypes-private.h"
-#include "gtksourcegutterrendererpixbuf.h"
 
 G_BEGIN_DECLS
 
@@ -38,23 +37,30 @@ G_BEGIN_DECLS
 #define GTK_SOURCE_GUTTER_RENDERER_MARKS_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_SOURCE_TYPE_GUTTER_RENDERER_MARKS, GtkSourceGutterRendererMarksClass))
 
 typedef struct _GtkSourceGutterRendererMarksClass	GtkSourceGutterRendererMarksClass;
+typedef struct _GtkSourceGutterRendererMarksPrivate	GtkSourceGutterRendererMarksPrivate;
 
 struct _GtkSourceGutterRendererMarks
 {
+	/*< private >*/
 	GtkSourceGutterRendererPixbuf parent;
+
+	GtkSourceGutterRendererMarksPrivate *priv;
+
+	/*< public >*/
 };
 
 struct _GtkSourceGutterRendererMarksClass
 {
+	/*< private >*/
 	GtkSourceGutterRendererPixbufClass parent_class;
+
+	/*< public >*/
 };
 
-G_GNUC_INTERNAL
 GType gtk_source_gutter_renderer_marks_get_type (void) G_GNUC_CONST;
 
-G_GNUC_INTERNAL
 GtkSourceGutterRenderer *gtk_source_gutter_renderer_marks_new (void);
 
 G_END_DECLS
 
-#endif /* GTK_SOURCE_GUTTER_RENDERER_MARKS_H */
+#endif /* __GTK_SOURCE_GUTTER_RENDERER_MARKS_H__ */
